==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-Mail");
define("_RE","Re");
define("_SUBJECT","Asunto");
define("_PRIVATEMESSAGES","As sas mensaxes privadas");
define("_CHECKALL","Ver todo");
define("_FROM","De");
define("_DATE","Fecha");
define("_DONTHAVEMESSAGES","Non ten mensaxes");
define("_NOTREAD","Non Ldo");
define("_MSGSTATUS","Estado da Mensaxe");
define("_PRIVATEMESSAGE","Mensaxe Privada");
define("_INDEX","ndice");
define("_SENT","Enviar");
define("_PREVIOUSMESSAGE","Mensaxe Anterior");
define("_NEXTMESSAGE","Mensaxe Seguinte");
define("_PROFILE","Perfil");
define("_ABOUTPOSTING","Acerca do Envo");
define("_ALLREGCANPOST","Os usuarios rexistrados poden enviar mensaxes privadas");
define("_TO","Para");
define("_MESSAGEICON","Icono da Mensaxe");
define("_MESSAGE","Mensaxe");
define("_HTML","HTML");
define("_PMON","s");
define("_PMOFF","non");
define("_BBCODE","CdigoBB");
define("_WROTE","escribiu");
define("_OPTIONS","Opcins");
define("_HTMLDISSABLE","Deshabilita HTML neste Envo");
define("_BBCODEDISSABLE","Deshabilitar <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> neste envo");
define("_SMILEDISSABLE","Deshabilitar <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> neste envo");
define("_CANCELREPLY","Cancelar Resposta");
define("_CANCELSEND","Cancelar Envo");
define("_CLEAR","Limpar");
define("_SUBMIT","Enviar");
define("_USERNOTINDB","O usuario non existe na Base de Datos");
define("_CHECKNAMEANDTRY","Por favor, chequee o nome e intenteo de novo");
define("_MSGPOSTED","A sa mensaxe foi enviada.");
define("_RETURNTOPMSG","Pode facer clic aqu para refrescar as sas mensaxes privadas.");
define("_MSGDELETED","As sas mensaxes foron borradas.");
define("_BBGO","vai");
define("_BBNEWPMSG","Novas Mensaxes");
define("_BBNONEWPMSG","Sen Novas Mensaxes");
define("_BBTOTALPMSG","Mensaxes Totales");
define("_BBEMPTYPMSG","Non ten Mensaxes");
define("_BBLOGIN","Lguese para ve-las sas Mensaxes Privadas");
define("_BBPMSG","Mensaxes Privadas");
define("_BBINBOX","Bandexa de Entrada");
define("_BBSELECTFORUM","Escolla un Foro");
define("_BBNOFORUM","Non hai mis Foros");
define("_BBBANNED","Expulsado");
define("_CLICKSMILEBUTTONS","Faga Clic nas carias para engadilas na sa Mensaxe:");
define("_CLICKCODEBUTTONS","Faga Clic nos botns para engadir BBCode na sa Mensaxe:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-Mail");
define("_RE","Re");
define("_SUBJECT","Asunto");
define("_PRIVATEMESSAGES","As sas mensaxes privadas");
define("_CHECKALL","Ver todo");
define("_FROM","De");
define("_DATE","Fecha");
define("_DONTHAVEMESSAGES","Non ten mensaxes");
define("_NOTREAD","Non Ldo");
define("_MSGSTATUS","Estado da Mensaxe");
define("_PRIVATEMESSAGE","Mensaxe Privada");
define("_INDEX","ndice");
define("_SENT","Enviar");
define("_PREVIOUSMESSAGE","Mensaxe Anterior");
define("_NEXTMESSAGE","Mensaxe Seguinte");
define("_PROFILE","Perfil");
define("_ABOUTPOSTING","Acerca do Envo");
define("_ALLREGCANPOST","Os usuarios rexistrados poden enviar mensaxes privadas");
define("_TO","Para");
define("_MESSAGEICON","Icono da Mensaxe");
define("_MESSAGE","Mensaxe");
define("_HTML","HTML");
define("_PMON","s");
define("_PMOFF","non");
define("_BBCODE","CdigoBB");
define("_WROTE","escribiu");
define("_OPTIONS","Opcins");
define("_HTMLDISSABLE","Deshabilita HTML neste Envo");
define("_BBCODEDISSABLE","Deshabilitar <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> neste envo");
define("_SMILEDISSABLE","Deshabilitar <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> neste envo");
define("_CANCELREPLY","Cancelar Resposta");
define("_CANCELSEND","Cancelar Envo");
define("_CLEAR","Limpar");
define("_SUBMIT","Enviar");
define("_USERNOTINDB","O usuario non existe na Base de Datos");
define("_CHECKNAMEANDTRY","Por favor, chequee o nome e intenteo de novo");
define("_MSGPOSTED","A sa mensaxe foi enviada.");
define("_RETURNTOPMSG","Pode facer clic aqu para refrescar as sas mensaxes privadas.");
define("_MSGDELETED","As sas mensaxes foron borradas.");
define("_BBGO","vai");
define("_BBNEWPMSG","Novas Mensaxes");
define("_BBNONEWPMSG","Sen Novas Mensaxes");
define("_BBTOTALPMSG","Mensaxes Totales");
define("_BBEMPTYPMSG","Non ten Mensaxes");
define("_BBLOGIN","Lguese para ve-las sas Mensaxes Privadas");
define("_BBPMSG","Mensaxes Privadas");
define("_BBINBOX","Bandexa de Entrada");
define("_BBSELECTFORUM","Escolla un Foro");
define("_BBNOFORUM","Non hai mis Foros");
define("_BBBANNED","Expulsado");
define("_CLICKSMILEBUTTONS","Faga Clic nas carias para engadilas na sa Mensaxe:");
define("_CLICKCODEBUTTONS","Faga Clic nos botns para engadir BBCode na sa Mensaxe:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
